// -*- c++ -*- 
//
// BeMailAccount
// Copyright (c) 2001, Okada Jun
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. The name of author may not be used to endorse or promote products
// derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 


#include <cstring>
#include <String.h>
#include <Message.h>
#include <MenuItem.h>
#include <E-mail.h>
#include "BMADefs.h"
#include "BMAProperty.h"
#include "BMAIcon.h"
#include "BMAMenu.h"


static const char *
sCheckDays[] = 
{
  "Never", 
  "Weekdays",
  "Everyday",
  "Continuously",
};

static struct
{
  const char *label;
  int32 interval;
}
sCheckInterval[] = 
{
  { "Minute",     60 },
  { "5 Minutes",  60 * 5 },
  { "10 Minutes", 60 * 10 },
  { "15 Minutes", 60 * 15 },
  { "30 Minutes", 60 * 30 },
  { "Hour",       60 * 60 },
};


BMAMenu::BMAMenu(BMAIcon *owner)
  : BPopUpMenu(NULL, false, false)
{
  BMAProperty *property = owner->Property();
  BMenuItem *item;
  BMenu *menu, *menu2;
  BMessage *msg;
  const char *activeAccount, *account;
  int32 i;
  
  activeAccount = property->ActiveAccount();

  for (i = 0; i < property->CountAccounts(); i++)
    {
      account = property->AccountAt(i);
      msg = new BMessage(BMA_SET_ACTIVE_ACCOUNT);
      msg->AddString("data", account);
      item = new BMenuItem(account, msg);
      if (activeAccount &&
	  ::strcmp(account, activeAccount) == 0)
	item->SetMarked(true);
      item->SetTarget(property);
      this->AddItem(item);
    }

  if (property->CountAccounts() == 0)
    {
      item = new BMenuItem("No Account", 0);
      item->SetEnabled(false);
      this->AddItem(item);
    }

  this->AddSeparatorItem();
  msg = new BMessage(BMA_LAUNCH_EMAIL_PREFS);
  item = new BMenuItem("E-mail Settings...", msg);
  item->SetTarget(property);
  this->AddItem(item);

  this->AddSeparatorItem();

  msg = new BMessage(BMA_NEW_ACCOUNT_REQUESTED);
  item = new BMenuItem("New Account", msg);
  item->SetTarget(property);
  this->AddItem(item);

  if (activeAccount)
    {
      msg = new BMessage(BMA_REMOVE_ACCOUNT_REQUESTED);
      msg->AddString("data", activeAccount);
      item = new BMenuItem("Remove Account", msg);
      item->SetTarget(property);
      this->AddItem(item);
    }

  this->AddSeparatorItem();

  menu = new BMenu("Mail Schedule");
  menu2 = new BMenu("Check Mail");
  for (i = 0; i < 4; i++)
    {
      msg = new BMessage(BMA_SET_CHECK_DAYS);
      msg->AddInt32("data", i);
      item = new BMenuItem(sCheckDays[i], msg);
      item->SetTarget(property);
      item->SetMarked(i == property->CheckDays());
      menu2->AddItem(item);
    }
  menu->AddItem(menu2);

  if (property->CheckDays() != B_CHECK_NEVER)
    {
      menu2 = new BMenu("Every");
      for (i = 0; i < 6; i++)
	{
	  msg = new BMessage(BMA_SET_CHECK_INTERVAL);
	  msg->AddInt32("data", sCheckInterval[i].interval);
	  item = new BMenuItem(sCheckInterval[i].label, msg);
	  item->SetTarget(property);
	  item->SetMarked
	    (sCheckInterval[i].interval == property->CheckInterval());
	  menu2->AddItem(item);
	}
      menu->AddItem(menu2);
    }

  if (property->CheckDays() == B_CHECK_WEEKDAYS ||
      property->CheckDays() == B_CHECK_DAILY)
    {
      menu2 = new BMenu("From");
      for (i = 0; i < 24 * 60 * 60; i += 60 * 60)
	{
	  BString buf;
	  buf << i / 3600 << ":00";
	  msg = new BMessage(BMA_SET_CHECK_BEGIN_TIME);
	  msg->AddInt32("data", i);
	  item = new BMenuItem(buf.String(), msg);
	  item->SetTarget(property);
	  item->SetMarked(i == property->CheckBeginTime());
	  menu2->AddItem(item);
	}
      menu->AddItem(menu2);
      
      menu2 = new BMenu("To");
      for (i = 0; i < 24 * 60 * 60; i += 60 * 60)
	{
	  BString buf;
	  buf << i / 3600 << ":00";
	  msg = new BMessage(BMA_SET_CHECK_END_TIME);
	  msg->AddInt32("data", i);
	  item = new BMenuItem(buf.String(), msg);
	  item->SetTarget(property);
	  item->SetMarked(i == property->CheckEndTime());
	  menu2->AddItem(item);
	}
      menu->AddItem(menu2);
    }

  this->AddItem(menu);

  msg = new BMessage(BMA_CHECK_NOW);
  item = new BMenuItem("Check Now", msg);
  item->SetTarget(property);
  this->AddItem(item);
}


BMAMenu::~BMAMenu(void)
{
}







